
-- The MIT License (MIT)

-- Copyright (c) 2014 Ak0 (Ak0.me)

-- Permission is hereby granted, free of charge, to any person obtaining a copy
-- of this software and associated documentation files (the "Software"), to deal
-- in the Software without restriction, including without limitation the rights
-- to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-- copies of the Software, and to permit persons to whom the Software is
-- furnished to do so, subject to the following conditions:

-- The above copyright notice notice shall be included in
-- all copies or substantial portions of the Software.

-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-- IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-- FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-- AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-- LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-- OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-- THE SOFTWARE.
---------------------------------------------------------------------------------

local AkORT = ZO_Object:Subclass()
-- Setup default config values.
AkORT.defaults = {
	enabledColor = {r=0.77254909276962, g=0.7607843875885, b=0.61960786581039},
	disabledColor = {r=0.40000003576279, g=0.40000003576279, b=0.40000003576279},
	interactableColor = {r=0.77254909276962, g=0.7607843875885, b=0.61960786581039},
	notInteractableColor = {r=0.40000003576279, g=0.40000003576279, b=0.40000003576279},
	titleColor = {r=0.77254909276962, g=0.7607843875885, b=0.61960786581039},
	recolorTitle = false,
}

-- Function that creates the settings panel.
function AkORT:Settings()

	-- Grab the awesome LibAddonMenu library.
	local LAM = LibStub:GetLibrary("LibAddonMenu-1.0")
	-- Define a new addon panel as panel.
	local panel = LAM:CreateControlPanel("AkOsAddons", "Ak0's Addons")

	-- Get user language.
	local function GetLang()
		local lang = GetCVar("language.2")
		if(lang == "en" or lang == "de" or lang == "fr") then return lang end
		return "en"
	end
	local lang = GetLang()
	-- Grab localized strings.
	local locale = AkORT_locale

	LAM:AddHeader(panel, "AkORT_ReticleTweaks", locale[lang].Addon)
	if self.config.recolorTitle == false then
	LAM:AddColorPicker(panel, "titlePicker", locale[lang].titlePicker.Header, locale[lang].titlePicker.Body,
		function() return self.config.titleColor.r, self.config.titleColor.g, self.config.titleColor.b end,
		function(r,g,b)
			self.config.titleColor = {r=r, g=g, b=b}
		end)
	else end
	LAM:AddCheckbox(panel, "AkORT_alsoRecolorTitle", locale[lang].alsoRecolorTitle.Header, locale[lang].alsoRecolorTitle.Body,
		function() return self.config.recolorTitle end, 
		function() 
			self.config.recolorTitle = not self.config.recolorTitle
			ReloadUI() 
		end, true, locale[lang].Warning)
	LAM:AddColorPicker(panel, "AkORT_interactablePicker", locale[lang].interactablePicker.Header, locale[lang].interactablePicker.Body, 
		function() return self.config.interactableColor.r, self.config.interactableColor.g, self.config.interactableColor.b end,
		function(r,g,b)
			self.config.interactableColor = {r=r, g=g, b=b}
		end)
	LAM:AddColorPicker(panel, "AkORT_notInteractablePicker", locale[lang].notInteractablePicker.Header, locale[lang].notInteractablePicker.Body, 
		function() return self.config.notInteractableColor.r, self.config.notInteractableColor.g, self.config.notInteractableColor.b end,
		function(r,g,b)
			self.config.notInteractableColor = {r=r, g=g, b=b}
		end)
	LAM:AddButton(panel, "AkORT_resetColors", locale[lang].resetColors.Header, locale[lang].resetColors.Body,
		function()
			self.config.interactableColor = {self.config.enabledColor.r, self.config.enabledColor.g, self.config.enabledColor.b}
			self.config.notInteractableColor = {self.config.disabledColor.r, self.config.disabledColor.g, self.config.disabledColor.b}
			self.config.titleColor = {self.config.enabledColor.r, self.config.enabledColor.g, self.config.enabledColor.b}
			ReloadUI()
		end, true, locale[lang].Warning)
	LAM:AddDescription(panel, "AkORT_credits", locale[lang].Credits)

end

-- Function that fires when the addon is loaded.
function AkORT:OnLoaded( event, addon )

	-- If we are anything but AkOsReticleTweaks, stop.
	if ( addon ~= "Ak0sReticleTweaks" ) then return end

	-- Initiate saved variables as self.config.
	self.config = ZO_SavedVars:NewAccountWide("AkORTDB", 1, nil, self.defaults)

	-- Set a OnUpdate handler on the Interact Keybind Button that handles the recoloring.
	ZO_ReticleContainerInteract:SetHandler("OnShow", function()
		-- Grab some variables.
		local action, _, _, additionalInfo, _ = GetGameCameraInteractableActionInfo()
		-- If action is "Search" or "Take": Recolor text.
		if action == GetString(SI_GAMECAMERAACTIONTYPE1) or action == GetString(SI_GAMECAMERAACTIONTYPE7) then
			if additionalInfo == ADDITIONAL_INTERACT_INFO_NONE then
                ZO_ReticleContainerInteractKeybindButtonNameLabel:SetColor(self.config.interactableColor.r, self.config.interactableColor.g, self.config.interactableColor.b)
            elseif additionalInfo == ADDITIONAL_INTERACT_INFO_EMPTY then
				ZO_ReticleContainerInteractKeybindButtonNameLabel:SetColor(self.config.notInteractableColor.r, self.config.notInteractableColor.g, self.config.notInteractableColor.b)
			end
		-- If action is not "Search" or "Take": Go back to normal colors.
		else
			if additionalInfo == ADDITIONAL_INTERACT_INFO_NONE then
                ZO_ReticleContainerInteractKeybindButtonNameLabel:SetColor(self.config.enabledColor.r, self.config.enabledColor.g, self.config.enabledColor.b)
            elseif additionalInfo == ADDITIONAL_INTERACT_INFO_EMPTY then
				ZO_ReticleContainerInteractKeybindButtonNameLabel:SetColor(self.config.disabledColor.r, self.config.disabledColor.g, self.config.disabledColor.b)
			end
		end
		-- If recolorTitle is true, recolor the title dynamicly.
		if self.config.recolorTitle == true then
			if action == GetString(SI_GAMECAMERAACTIONTYPE1) or action == GetString(SI_GAMECAMERAACTIONTYPE7) then
				if additionalInfo == ADDITIONAL_INTERACT_INFO_NONE then
	                ZO_ReticleContainerInteractContext:SetColor(self.config.interactableColor.r, self.config.interactableColor.g, self.config.interactableColor.b)
	            elseif additionalInfo == ADDITIONAL_INTERACT_INFO_EMPTY then
					ZO_ReticleContainerInteractContext:SetColor(self.config.notInteractableColor.r, self.config.notInteractableColor.g, self.config.notInteractableColor.b)
				end
			else
				ZO_ReticleContainerInteractContext:SetColor(self.config.enabledColor.r, self.config.enabledColor.g, self.config.enabledColor.b)
			end
		-- else use a fixed color for the title.
		else
			if action == GetString(SI_GAMECAMERAACTIONTYPE1) or action == GetString(SI_GAMECAMERAACTIONTYPE7) then
				ZO_ReticleContainerInteractContext:SetColor(self.config.titleColor.r, self.config.titleColor.g, self.config.titleColor.b)
			else
				ZO_ReticleContainerInteractContext:SetColor(self.config.enabledColor.r, self.config.enabledColor.g, self.config.enabledColor.b)
			end
		end
	end)

	-- Initiate settings panel.
	self:Settings()
	-- Unregister Addon.
	EVENT_MANAGER:UnregisterForEvent( "Ak0sReticleTweaks", EVENT_ADD_ON_LOADED )

end

EVENT_MANAGER:RegisterForEvent( "Ak0sReticleTweaks", EVENT_ADD_ON_LOADED, function(...) AkORT:OnLoaded(...) end )